@@ -37,6 +37,7 @@ class BaseSession(object):
 
     def __init__(self, session                    = None, timeout      = 10,
                  verify_ssl       = True)        :
+        self._shared_session = bool(session)
         self._session = session
         self._ssl = verify_ssl
         self._timeout = timeout
@@ -53,7 +54,14 @@ class BaseSession(object):
 
     @abstractmethod
     def get(self, url     , headers                          ,
-                  timeout     , params                          )            :
+                  timeout     , params                          ,
+                  stream      )            :
+        pass
+
+    @abstractmethod
+    def patch(self, url     , headers                ,
+                    data               , timeout     ,
+                    params                          )            :
         pass
 
     @abstractmethod
@@ -111,9 +119,10 @@ if not BUILD_GCLOUD_REST:
     class AioSession(BaseSession):
         @property
         def session(self)                         :
-            connector = aiohttp.TCPConnector(ssl=self._ssl)
-            self._session = self._session or aiohttp.ClientSession(
-                connector=connector, timeout=self._timeout)
+            if not self._session:
+                connector = aiohttp.TCPConnector(ssl=self._ssl)
+                self._session = aiohttp.ClientSession(connector=connector,
+                                                      timeout=self._timeout)
             return self._session
 
         def post(self, url     , headers                ,
@@ -127,13 +136,26 @@ if not BUILD_GCLOUD_REST:
 
         def get(self, url     , headers                           = None,
                       timeout      = 10,
-                      params                           = None
-                      )                          :
+                      params                           = None,
+                      stream                 = None)                          :
+            if stream is not None:
+                log.warning('passed unused argument stream=%s to AioSession: '
+                            'this argument is only used by SyncSession',
+                            stream)
             resp = self.session.get(url, headers=headers,
                                           timeout=timeout, params=params)
             _raise_for_status(resp)
             return resp
 
+        def patch(self, url     , headers                ,
+                        data                = None, timeout      = 10,
+                        params                           = None
+                        )                          :
+            resp = self.session.patch(url, data=data, headers=headers,
+                                            timeout=timeout, params=params)
+            _raise_for_status(resp)
+            return resp
+
         def put(self, url     , headers                , data         ,
                       timeout      = 10)                          :
             resp = self.session.put(url, data=data, headers=headers,
@@ -160,7 +182,7 @@ if not BUILD_GCLOUD_REST:
             return resp
 
         def close(self)        :
-            if self._session:
+            if not self._shared_session and self._session:
                 self._session.close()  # type: ignore[func-returns-value]
 
 
@@ -174,8 +196,9 @@ if BUILD_GCLOUD_REST:
 
         @property
         def session(self)           :
-            self._session = self._session or Session()
-            self._session.verify = self._ssl
+            if not self._session:
+                self._session = Session()
+                self._session.verify = self._ssl
             return self._session
 
         # N.B.: none of these will be `async` in compiled form, but adding the
@@ -192,10 +215,20 @@ if BUILD_GCLOUD_REST:
 
         def get(self, url     , headers                           = None,
                       timeout      = 10,
-                      params                           = None)            :
+                      params                           = None,
+                      stream       = False)            :
             with self.google_api_lock:
                 resp = self.session.get(url, headers=headers, timeout=timeout,
-                                        params=params)
+                                        params=params, stream=stream)
+            resp.raise_for_status()
+            return resp
+
+        def patch(self, url     , headers                ,
+                        data                = None, timeout      = 10,
+                        params                           = None)            :
+            with self.google_api_lock:
+                resp = self.session.patch(url, data=data, headers=headers,
+                                          timeout=timeout, params=params)
             resp.raise_for_status()
             return resp
 
@@ -228,5 +261,5 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def close(self)        :
-            if self._session:
+            if not self._shared_session and self._session:
                 self._session.close()
